pub enum EventDeviceKind {
Mouse,
Touchscreen,
Keyboard,
}Variants
Mouse
Produces relative mouse motions, wheel, and button clicks while the real mouse is captured.
Touchscreen
Produces absolute motion and touch events from the display window’s events.
Keyboard
Produces key events while the display window has focus.